@@ -1346,10 +1346,8 @@ class Subscription(Generic[T]):
                 **self.filters_param,
             },
         ) as response:
-            logger.debug(
-                "Got response %s while requesting subscription channel", response
-            )
             data = await response.json()
+            logger.debug("Got response %s while requesting subscription channel", data)
             if data.get("error") is not None:
                 raise errors.SubscribeError(data["error"])
             return data["channel"]
@@ -1494,13 +1492,14 @@ class Socket:
     async def actual_run(self) -> None:
         while True:
             try:
+                logger.debug("Waiting for connected WS %s", self.ws)
                 await self.connected.wait()
                 logger.debug("Listening for messages WS %s", self.ws)
                 async for message in self.ws:
                     try:
                         # message.type is Unknown
                         if message.type in {aiohttp.WSMsgType.CLOSED, aiohttp.WSMsgType.CLOSING, aiohttp.WSMsgType.CLOSE}:  # type: ignore
-                            await self.handle_socket_close()
+                            asyncio.create_task(self.handle_socket_close())
                         elif message.type not in {aiohttp.WSMsgType.TEXT}:  # type: ignore
                             continue
                         # message.data is Unknown
@@ -1540,7 +1539,7 @@ class Socket:
                         logging.warning(
                             "Encountered ConnectionResetError in socket", exc_info=e
                         )
-                        await self.close_and_reconnect()
+                        asyncio.create_task(self.close_and_reconnect())
                         break
                     except Exception as e:
                         utils.print_exception_with_header(
@@ -1553,7 +1552,7 @@ class Socket:
                 if self.ws.closed:
                     self.connected.clear()
                     logger.debug("actual_run -> Socket closed WS %s", self.ws)
-                    await self.handle_socket_close()
+                    asyncio.create_task(self.handle_socket_close())
             except asyncio.TimeoutError as e:
                 utils.print_exception_with_header("Encountered exception in socket", e)
                 logging.warning("Encountered exception in socket", exc_info=e)
@@ -1609,7 +1608,8 @@ class Socket:
                 self.last_ping = time.perf_counter()
             except ConnectionResetError:
                 logger.debug("ping_pong - Connection reset")
-                asyncio.create_task(self.close_and_reconnect(b"Connection reset"))
+                await self.close_and_reconnect(b"Connection reset")
+                await asyncio.sleep(self.activity_timeout)
 
     def run(self) -> None:
         self.task = asyncio.create_task(self.actual_run())
@@ -1630,10 +1630,10 @@ class Socket:
             self.kit.subscription_auth_url,
             data={"socket_id": self.socket_id, "channel_name": subscription.channel},
         ) as response:
-            logger.debug("authorize_subscription - Got response %s", response)
             if response.status != 200:
                 raise errors.Unauthorized()
             data = await response.json()
+            logger.debug("authorize_subscription - Got response %s", data)
             self.kit.check_response_for_errors(data)
             return data["auth"]
         raise errors.SubscribeError(
